;;*****************************************************************************
;;  FILENAME: CMX_CSD_CHAN.asm
;;   @Versions@
;;  
;;
;;  DESCRIPTION: Asm source file for CMX_CSD_CHAN.
;;               
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2000-2006. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "CSD.inc"

export _CSD_UpdateGroupBaselines
export  CSD_UpdateGroupBaselines
export _CSD_InitializeGroupBaselines
export  CSD_InitializeGroupBaselines
export _CSD_ScanSensorGroup
export  CSD_ScanSensorGroup
export _CSD_GetGroupSensorIndex
export  CSD_GetGroupSensorIndex


AREA UserModules (ROM, REL)

; For using two byte variables
LSB:  equ  1
MSB:  equ  0

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: CSD_UpdateGroupBaselines(BYTE bSnsGroup)
;
;  DESCRIPTION: Updates baseline for a sensor group
;-----------------------------------------------------------------------------
;  STACK USAGE: 3 BYTES
;
;  ARGUMENTS: 
;      A => Sensor Group
;       Sensor Group = 0 for the independent sensors group
;       Sensor Group = 1 for the first slider group
;       Sensor Group = 2 for the second slider group
;    
;  RETURNS:    
;      None
;                
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;

 CSD_UpdateGroupBaselines:
_CSD_UpdateGroupBaselines:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR 0 ; direct ram will always be in interrupt ram area
   
; First get the starting location and size of this sensor group
   asl   A ; multiply by six to get group offset
   mov   [CSD_bSnsMaskPtr], A ; use as temp
   asl   A
   add   A,[CSD_bSnsMaskPtr]
   add   A,<CSD_Group_Table
   mov   X,A
   mov   A,>CSD_Group_Table                ; Get MSB of CSD_Group_Table        ( Swap Later )
   romx
   mov   [CSD_bSnsMaskPtr],A               ; use as temp
   inc   X   
   mov   A,>CSD_Group_Table
   romx
   mov   X,A                               ; A now has starting sensor number, x has size of group
   mov   A,[CSD_bSnsMaskPtr] 

.UpdGroupBaselinesLoop:                                      ; Loop through the sensor group
   push  X
   push	 A
   lcall  CSD_UpdateSensorBaseline
   pop   A
   inc   A
   pop   X
   dec   X
   
   jnz   .UpdGroupBaselinesLoop

   RAM_EPILOGUE RAM_USE_CLASS_4
   ret

.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: CSD_InitializeGroupBaselines(BYTE bSnsGroup)
;
;  DESCRIPTION: Initialize baseline for a sensor group
;-----------------------------------------------------------------------------
;  STACK USAGE: 3 BYTES
;
;  ARGUMENTS: 
;      A => Sensor Group
;       Sensor Group = 0 for the independent sensors group
;       Sensor Group = 1 for the first slider group
;       Sensor Group = 2 for the second slider group
;    
;  RETURNS:    
;      None
;                
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;

 CSD_InitializeGroupBaselines:
_CSD_InitializeGroupBaselines:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR 0 ; direct ram will always be in interrupt ram area
   
; First get the starting location and size of this sensor group
   asl   A ; multiply by six to get group offset
   mov   [CSD_bSnsMaskPtr], A ; use as temp
   asl   A
   add   A,[CSD_bSnsMaskPtr]
   add   A,<CSD_Group_Table
   mov   X,A
   mov   A,>CSD_Group_Table                ; Get MSB of CSD_Group_Table        ( Swap Later )
   romx
   mov   [CSD_bSnsMaskPtr],A               ; use as temp
   inc   X   
   mov   A,>CSD_Group_Table
   romx
   mov   X,A                               ; A now has starting sensor number, x has size of group
   mov   A,[CSD_bSnsMaskPtr] 

.InitGroupBaselinesLoop:                                      ; Loop through the sensor group
   push  X
   push	 A
   lcall  CSD_InitializeSensorBaseline
   pop   A
   inc   A
   pop   X
   dec   X
   
   jnz   .InitGroupBaselinesLoop

   RAM_EPILOGUE RAM_USE_CLASS_4
   ret

.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: CSD_ScanSensorGroup(BYTE bSnsGroup)
;
;  DESCRIPTION: Scans all sensors in a group
;-----------------------------------------------------------------------------
;  STACK USAGE: 3 BYTES
;
;  ARGUMENTS: 
;      A => Sensor Group
;       Sensor Group = 0 for the independent sensors group
;       Sensor Group = 1 for the first slider group
;       Sensor Group = 2 for the second slider group
;    
;  RETURNS:    
;      None
;                          
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;

 CSD_ScanSensorGroup:
_CSD_ScanSensorGroup:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR 0 ; direct ram will always be in interrupt ram area
   
; First get the starting location and size of this sensor group
   asl   A ; multiply by six to get group offset
   mov   [CSD_bSnsMaskPtr], A ; use as temp
   asl   A
   add   A,[CSD_bSnsMaskPtr]
   add   A,<CSD_Group_Table
   mov   X,A
   mov   A,>CSD_Group_Table                ; Get MSB of CSD_Group_Table        ( Swap Later )
   romx
   mov   [CSD_bSnsMaskPtr],A               ; use as temp
   inc   X   
   mov   A,>CSD_Group_Table
   romx
   mov   X,A                               ; A now has starting sensor number, x has size of group
   mov   A,[CSD_bSnsMaskPtr] 

.ScanSensorGroupLoop:                                      ; Loop through the sensor group
   push  X
   push	 A
   lcall  CSD_ScanSensor
   pop   A
   inc   A
   pop   X
   dec   X
   
   jnz   .ScanSensorGroupLoop

   RAM_EPILOGUE RAM_USE_CLASS_4
   ret

.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: CSD_GetGroupSensorIndex(BYTE bSnsGroup)
;
;  DESCRIPTION: Returns the starting index of the sensor group
;-----------------------------------------------------------------------------
;  STACK USAGE: 3 BYTES
;
;  ARGUMENTS: 
;      A => Sensor Group
;       Sensor Group = 0 for the independent sensors group
;       Sensor Group = 1 for the first slider group
;       Sensor Group = 2 for the second slider group
;   	 
;  RETURNS:    
;      BYTE  - starting index of sensor group
;                          
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;

 CSD_GetGroupSensorIndex:
_CSD_GetGroupSensorIndex:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR 0 ; direct ram will always be in interrupt ram area
   
; First get the starting location and size of this sensor group
   asl   A ; multiply by six to get group offset
   mov   [CSD_bSnsMaskPtr], A ; use as temp
   asl   A
   add   A,[CSD_bSnsMaskPtr]
   add   A,<CSD_Group_Table
   mov   X,A
   mov   A,>CSD_Group_Table                ; Get MSB of CSD_Group_Table        ( Swap Later )
   romx
   mov   [CSD_bSnsMaskPtr],A               ; use as temp
   inc   X   
   mov   A,>CSD_Group_Table
   romx
   mov   X,A                               ; A now has starting sensor number, x has size of group
   mov   A,[CSD_bSnsMaskPtr] 

   RAM_EPILOGUE RAM_USE_CLASS_4
   ret

.ENDSECTION

